{% extends "vendor/base.html" %}
{% load crispy_forms_tags %}
{% load i18n %}
{% block content %}
<div class='card'>
    <div class='card-header'>
        <h1>{{ integration_name }}</h1>
    </div>
    <div class='card-body'>
        <form method="POST">
            {% csrf_token %}
            {{ form|crispy }}
            <div class='form-group'>
                <button type="submit" class="btn btn-success">{% trans 'Apply' %}</button>
            </div>
        </form>
    </div>
    {% endblock %}
</div>