{% extends "vendor/manage/base.html" %}
{% load i18n %}


{% block title %}{{ title|default:"Config" }}{% endblock %}

{% block content %}
<form method="POST" >
    {% csrf_token %}
    {{ form.as_p }}
    <a class="btn btn-danger" href="{{ cancel_url}}">{% trans 'Cancel' %}</a>
    <input type="submit" value="Save" class="btn btn-primary">
</form>
{% endblock %}