# Generated by Django 3.2.14 on 2022-07-19 09:44

from django.db import migrations, models
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('vendor', '0037_auto_20220609_1644'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='payment',
            managers=[
                ('reports', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name='subscription',
            managers=[
                ('reports', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='payment',
            name='submitted_date',
            field=models.DateTimeField(blank=True, default=None, null=True, verbose_name='Payment Date'),
        ),
    ]
